# White Renamer

White Renamer is free software that batch rename files and folders.

![screenshot1](/Screenshots/MainLayout.png)

## Why another batch renamer ?

Most free batch renamers look like this :

![screenshot1](/Screenshots/SuperRenamer.png)
* They are clumsy and difficult to use.
* The options are too scattered in the window.
* The order in which the options are applied is unclear.

It is in the optic of making a powerful but still user-friendly software that White Renamer is born.
White Renamer has a simple UI containing two distinct parts : the top part displays boxes representing the structure of the files (file + extension or folder).
Each box contains actions to modify the desired file part. A possibility to add prefixes and suffixes is also available.
The bottom part displays a live preview of the changes made to the files/folders.

## Main Features
* Batch rename files, folders or both.
* Change subfolders, subfiles recursively.
* Change the case (uppercase, lowercase, titlecase).
* Use images EXIF metadata.
* Use music metadata.
* Use custom names.
* Use the parent folder's name.
* Find and replace characters.
* Remove or insert characters.
* Add counter.
* Append or prepend any of the above actions by using prefixes or suffixes.
* Filter the files to change.
* Preview the changes automatically.
* Undo changes.
* Sort directories.
* Cross-platform support.

## Build
The builds can be found at this address :
![https://github.com/pierrecnalb/WhiteRenamer-builds](https://github.com/pierrecnalb/WhiteRenamer-builds)

## Dependencies
* python3
* exifread
* pyqt5
* mutagen

## License
White Renamer is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

White Renamer is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY.

See the GNU General Public License for more details.

## Maintainer
Pierre BLANC<[pierrecnalb@mailbox.org](mailto:pierrecnalb@mailbox.org)>
